tlslite.messages.ApplicationData

Package tlslite :: Module messages :: Class ApplicationData |
[show private | hide private]
[frames | no frames]

## Class ApplicationData

    Msg --+
          |
         ApplicationData

Method Summary
| `__init__(self)`
| `create(self, bytes)`
| `parse(self, p)`
| `write(self)`
Inherited from Msg
| ``postWrite`(self, w, trial)`
| ``preWrite`(self, trial)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net